@@ -13,9 +13,20 @@ from tdxapi.managers.configuration_relationship_type import (
 from tdxapi.managers.custom_attribute import CustomAttributeManager
 from tdxapi.managers.custom_attribute_choice import CustomAttributeChoiceManager
 from tdxapi.managers.functional_role import FunctionalRoleManager
+from tdxapi.managers.impact import ImpactManager
+from tdxapi.managers.location import LocationManager
+from tdxapi.managers.location_room import LocationRoomManager
+from tdxapi.managers.priority import PriorityManager
 from tdxapi.managers.product_model import ProductModelManager
 from tdxapi.managers.product_type import ProductTypeManager
 from tdxapi.managers.report import ReportManager
 from tdxapi.managers.resource_pool import ResourcePoolManager
 from tdxapi.managers.security_role import SecurityRoleManager
+from tdxapi.managers.ticket import TicketManager
+from tdxapi.managers.ticket_app import TicketApplication
+from tdxapi.managers.ticket_source import TicketSourceManager
+from tdxapi.managers.ticket_status import TicketStatusManager
+from tdxapi.managers.ticket_task import TicketTaskManager
+from tdxapi.managers.ticket_type import TicketTypeManager
+from tdxapi.managers.urgency import UrgencyManager
 from tdxapi.managers.vendor import VendorManager
