@@ -1,5 +1,5 @@
 from datetime import datetime
-from typing import Optional
+from typing import List, Optional
 
 import attr
 
@@ -15,6 +15,7 @@ from tdxapi.managers.mixins import TdxAppMixin
 from tdxapi.managers.product_model import ProductModelManager
 from tdxapi.managers.product_type import ProductTypeManager
 from tdxapi.managers.vendor import VendorManager
+from tdxapi.models.form import Form
 from tdxapi.models.item_updates_page import ItemUpdatesPage
 
 
@@ -22,9 +23,13 @@ from tdxapi.models.item_updates_page import ItemUpdatesPage
 class AssetApplication(TdxManager, TdxAppMixin):
     def __attrs_post_init__(self):
         self.assets = AssetManager(self.dispatcher, self.app_id)
-        self.cis = ConfigurationItemManager(self.dispatcher, self.app_id)
-        self.ci_types = ConfigurationItemTypeManager(self.dispatcher, self.app_id)
-        self.ci_relationship_types = ConfigurationRelationshipTypeManager(
+        self.configuration_items = ConfigurationItemManager(
+            self.dispatcher, self.app_id
+        )
+        self.configuration_item_types = ConfigurationItemTypeManager(
+            self.dispatcher, self.app_id
+        )
+        self.configuration_relationship_types = ConfigurationRelationshipTypeManager(
             self.dispatcher, self.app_id
         )
         self.product_models = ProductModelManager(self.dispatcher, self.app_id)
@@ -38,7 +43,7 @@ class AssetApplication(TdxManager, TdxAppMixin):
         "?DateFrom={DateFrom}&DateTo={DateTo}"
         "&ReplyCount={ReplyCount}&ReturnCount={ReturnCount}",
     )
-    def get_feed(
+    def get_feed_page(
         self,
         date_from: Optional[datetime] = None,
         date_to: Optional[datetime] = None,
@@ -57,8 +62,8 @@ class AssetApplication(TdxManager, TdxAppMixin):
             be in the range 1-100, and will default to 25.
         """
         return self.dispatcher.send(
-            self.get_feed.method,
-            self.get_feed.url.format(
+            self.get_feed_page.method,
+            self.get_feed_page.url.format(
                 appId=self.app_id,
                 DateFrom=date_from,
                 DateTo=date_to,
@@ -69,3 +74,25 @@ class AssetApplication(TdxManager, TdxAppMixin):
             rlist=False,
             rpartial=True,
         )
+
+    @tdx_method("GET", "/api/{appId}/assets/forms")
+    def get_asset_forms(self) -> List[Form]:
+        """Gets all active asset forms for the specified application."""
+        return self.dispatcher.send(
+            self.get_asset_forms.method,
+            self.get_asset_forms.url.format(appId=self.app_id),
+            rclass=Form,
+            rlist=True,
+            rpartial=True,
+        )
+
+    @tdx_method("GET", "/api/{appId}/cmdb/forms")
+    def get_configuration_item_forms(self) -> List[Form]:
+        """Gets all active configuration item forms for the specified application."""
+        return self.dispatcher.send(
+            self.get_configuration_item_forms.method,
+            self.get_configuration_item_forms.url.format(appId=self.app_id),
+            rclass=Form,
+            rlist=True,
+            rpartial=True,
+        )
