@@ -1,4 +1,4 @@
-from typing import Any
+from typing import Any, Optional
 
 import attr
 
@@ -9,9 +9,11 @@ from tdxapi.models.attachment import Attachment
 @attr.s
 class AttachmentManager(TdxManager):
     @tdx_method("GET", "/api/attachments/{id}")
-    def get(self, attachment_id: str) -> Attachment:
+    def get(
+        self, attachment_id: str, with_content: Optional[bool] = False
+    ) -> Attachment:
         """Gets an attachment."""
-        return self.dispatcher.send(
+        attachment = self.dispatcher.send(
             self.get.method,
             self.get.url.format(id=attachment_id),
             rclass=Attachment,
@@ -19,6 +21,11 @@ class AttachmentManager(TdxManager):
             rpartial=False,
         )
 
+        if attachment and with_content:
+            attachment.content = self.get_content(attachment_id)
+
+        return attachment
+
     @tdx_method("GET", "/api/attachments/{id}/content")
     def get_content(self, attachment_id: str) -> Any:
         """Gets the contents of an attachment."""
