@@ -11,7 +11,6 @@ from tdxapi.models.configuration_item import ConfigurationItem
 from tdxapi.models.configuration_item_relationship import ConfigurationItemRelationship
 from tdxapi.models.configuration_item_search import ConfigurationItemSearch
 from tdxapi.models.feed_entry import FeedEntry
-from tdxapi.models.form import Form
 from tdxapi.models.item_update import ItemUpdate
 from tdxapi.models.ticket_listing import TicketListing
 
@@ -41,7 +40,7 @@ class ConfigurationItemManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin)
         self,
         name_like: Optional[str] = None,
         type_ids: Optional[List[int]] = None,
-        custom_attributes: Optional[List[Tuple[int, Any]]] = None,
+        attributes: Optional[List[Tuple[int, Any]]] = None,
         maintenance_schedule_ids: Optional[List[int]] = None,
         is_active: Optional[bool] = None,
     ) -> List[ConfigurationItem]:
@@ -49,11 +48,11 @@ class ConfigurationItemManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin)
 
         :param name_like: the name text to filter on.
         :param type_ids: the type IDs to filter on.
-        :param custom_attributes: the custom attributes to filter on.
+        :param attributes: the custom attributes to filter on.
         :param maintenance_schedule_ids: the maintenance window IDs to filter on.
         :param is_active: the active status to filter on.
         """
-        params = helpers.format_search_params(ConfigurationItemSearch, self, locals())
+        params = self._format_search_params(ConfigurationItemSearch, locals())
 
         return self.dispatcher.send(
             self.search.method,
@@ -82,11 +81,13 @@ class ConfigurationItemManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin)
         )
 
     @tdx_method("GET", "/api/{appId}/cmdb/{id}/feed")
-    def get_feed(self, configuration_item_id: int) -> List[ItemUpdate]:
+    def get_feed_entries(self, configuration_item_id: int) -> List[ItemUpdate]:
         """Gets the feed for the configuration items."""
         return self.dispatcher.send(
-            self.get_feed.method,
-            self.get_feed.url.foramt(appId=self.app_id, id=configuration_item_id),
+            self.get_feed_entries.method,
+            self.get_feed_entries.url.foramt(
+                appId=self.app_id, id=configuration_item_id
+            ),
             rclass=ItemUpdate,
             rlist=True,
             rpartial=True,
@@ -183,33 +184,22 @@ class ConfigurationItemManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin)
             rpartial=True,
         )
 
-    @tdx_method("GET", "/api/{appId}/cmdb/forms")
-    def get_forms(self) -> List[Form]:
-        """Gets all active configuration item forms for the specified application."""
-        return self.dispatcher.send(
-            self.get_forms.method,
-            self.get_forms.url.format(appId=self.app_id),
-            rclass=Form,
-            rlist=True,
-            rpartial=True,
-        )
-
     def new(self, **kwargs) -> ConfigurationItem:
         """Generate new ConfigurationItem object."""
-        return helpers.new_model(ConfigurationItem, self, **kwargs)
+        return self._new(ConfigurationItem, **kwargs)
 
     def save(
         self, configuration_item: ConfigurationItem, force: Optional[bool] = False
     ) -> None:
         """Create or update a ConfigurationItem."""
-        helpers.save_model(configuration_item, self, force)
+        self._save(configuration_item, force)
 
     @tdx_method("POST", "/api/{appId}/cmdb")
-    def _insert(self, configuration_item: ConfigurationItem) -> ConfigurationItem:
+    def _create(self, configuration_item: ConfigurationItem) -> ConfigurationItem:
         """Creates a configuration item."""
         return self.dispatcher.send(
-            self._insert.method,
-            self._insert.url.format(appId=self.app_id),
+            self._create.method,
+            self._create.url.format(appId=self.app_id),
             data=configuration_item,
             rclass=ConfigurationItem,
             rlist=False,
