@@ -2,7 +2,6 @@ from typing import List, Optional
 
 import attr
 
-from tdxapi.managers import helpers
 from tdxapi.managers.bases import TdxManager, tdx_method
 from tdxapi.models.functional_role import FunctionalRole
 from tdxapi.models.functional_role_search import FunctionalRoleSearch
@@ -32,7 +31,7 @@ class FunctionalRoleManager(TdxManager):
             functional role selections, as Admin selections will always include item
             counts.
         """
-        params = helpers.format_search_params(FunctionalRoleSearch, self, locals())
+        params = self._format_search_params(FunctionalRoleSearch, locals())
 
         return self.dispatcher.send(
             self.search.method,
@@ -45,20 +44,20 @@ class FunctionalRoleManager(TdxManager):
 
     def new(self, **kwargs) -> FunctionalRole:
         """Generate new FunctionalRole object."""
-        return helpers.new_model(FunctionalRole, self, **kwargs)
+        return self._new(FunctionalRole, **kwargs)
 
     def save(
         self, functional_role: FunctionalRole, force: Optional[bool] = False
     ) -> None:
         """Create or update a FunctionalRole."""
-        helpers.save_model(functional_role, self, force)
+        self._save(functional_role, force)
 
     @tdx_method("POST", "/api/functionalroles")
-    def _insert(self, functional_role: FunctionalRole) -> FunctionalRole:
+    def _create(self, functional_role: FunctionalRole) -> FunctionalRole:
         """Creates a functional role."""
         return self.dispatcher.send(
-            self._insert.method,
-            self._insert.url,
+            self._create.method,
+            self._create.url,
             data=functional_role,
             rclass=FunctionalRole,
             rlist=False,
