@@ -2,7 +2,6 @@ from typing import List, Optional
 
 import attr
 
-from tdxapi.managers import helpers
 from tdxapi.managers.bases import TdxManager, tdx_method
 from tdxapi.models.resource_pool import ResourcePool
 from tdxapi.models.resource_pool_search import ResourcePoolSearch
@@ -34,7 +33,7 @@ class ResourcePoolManager(TdxManager):
             be retrieved for each pool. Defaults to false.
         :param max_results: the maximum number of records to return.
         """
-        params = helpers.format_search_params(ResourcePoolSearch, self, locals())
+        params = self._format_search_params(ResourcePoolSearch, locals())
 
         return self.dispatcher.send(
             self.search.method,
@@ -47,18 +46,18 @@ class ResourcePoolManager(TdxManager):
 
     def new(self, **kwargs) -> ResourcePool:
         """Generate new ResourcePool object."""
-        return helpers.new_model(ResourcePool, self, **kwargs)
+        return self._new(ResourcePool, **kwargs)
 
     def save(self, resource_pool: ResourcePool, force: Optional[bool] = False) -> None:
         """Create or update a ResourcePool."""
-        helpers.save_model(resource_pool, self, force)
+        self._save(resource_pool, force)
 
     @tdx_method("POST", "/api/resourcepools")
-    def _insert(self, resource_pool: ResourcePool) -> ResourcePool:
+    def _create(self, resource_pool: ResourcePool) -> ResourcePool:
         """Creates a resource pool."""
         return self.dispatcher.send(
-            self._insert.method,
-            self._insert.url,
+            self._create.method,
+            self._create.url,
             data=resource_pool,
             rclass=ResourcePool,
             rlist=False,
