@@ -13,7 +13,6 @@ from tdxapi.managers.bases import TdxManager, tdx_method
 from tdxapi.managers.mixins import TdxAppMixin, TdxCustomAttributeMixin
 from tdxapi.models.attachment import Attachment
 from tdxapi.models.configuration_item import ConfigurationItem
-from tdxapi.models.form import Form
 from tdxapi.models.item_update import ItemUpdate
 from tdxapi.models.sla_assignment_options import SlaAssignmentOptions
 from tdxapi.models.sla_removal_options import SlaRemovalOptions
@@ -109,7 +108,7 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         location_ids: Optional[List[int]] = None,
         location_room_ids: Optional[List[int]] = None,
         service_ids: Optional[List[int]] = None,
-        custom_attributes: Optional[List[Tuple[int, Any]]] = None,
+        attributes: Optional[List[Tuple[int, Any]]] = None,
         has_reference_code: Optional[bool] = None,
     ) -> List[Ticket]:
         """Gets a list of tickets.
@@ -187,11 +186,11 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         :param location_ids: The associated location IDs to filter on.
         :param location_room_ids: The associated location room IDs to filter on.
         :param service_ids: The associated service IDs to filter on.
-        :param custom_attributes: The associated custom attributes to filter on.
+        :param attributes: The associated custom attributes to filter on.
         :param has_reference_code: Whether the returned tickets should have a reference
             code.
         """
-        params = helpers.format_search_params(TicketSearch, self, locals())
+        params = self._format_search_params(TicketSearch, locals())
 
         return self.dispatcher.send(
             self.search.method,
@@ -315,11 +314,11 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         )
 
     @tdx_method("GET", "/api/{appId}/tickets/{id}/feed")
-    def get_feed(self, ticket_id: int) -> List[ItemUpdate]:
+    def get_feed_entries(self, ticket_id: int) -> List[ItemUpdate]:
         """Gets the feed entries for a ticket."""
         return self.dispatcher.send(
-            self.get_feed.method,
-            self.get_feed.url.format(appId=self.app_id, id=ticket_id),
+            self.get_feed_entries.method,
+            self.get_feed_entries.url.format(appId=self.app_id, id=ticket_id),
             rclass=ItemUpdate,
             rlist=True,
             rpartial=True,
@@ -416,20 +415,9 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
             rpartial=True,
         )
 
-    @tdx_method("GET", "/api/{appId}/tickets/forms")
-    def get_forms(self) -> List[Form]:
-        """Gets all active ticket forms for the specified application."""
-        return self.dispatcher.send(
-            self.get_forms.method,
-            self.get_forms.url.format(appId=self.app_id),
-            rclass=Form,
-            rlist=True,
-            rpartial=True,
-        )
-
     def new(self, **kwargs) -> Ticket:
         """Generate new Ticket object."""
-        return helpers.new_model(Ticket, self, **kwargs)
+        return self._new(Ticket, **kwargs)
 
     def save(
         self,
@@ -442,24 +430,20 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         force: Optional[bool] = False,
     ) -> None:
         """Create or update a Ticket."""
-        if not force:
-            helpers.save_check(ticket)
-
         if ticket.id:
-            updated_model = self._update(
-                ticket, notify_new_responsible=on_update_notify_new_responsible
+            self._save(
+                ticket, force, notify_new_responsible=on_update_notify_new_responsible
             )
         else:
-            updated_model = self._insert(
+            self._save(
                 ticket,
+                force,
                 notify_reviewer=on_create_notify_reviewer,
                 notify_requestor=on_create_notify_requestor,
                 notify_responsible=on_create_notify_responsible,
                 allow_requestor_creation=on_create_allow_requestor_creation,
             )
 
-        helpers.update_model(ticket, updated_model)
-
     @tdx_method(
         "POST",
         "/api/{appId}/tickets"
@@ -468,7 +452,7 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
         "&NotifyResponsible={NotifyResponsible}"
         "&AllowRequestorCreation={AllowRequestorCreation}",
     )
-    def _insert(
+    def _create(
         self,
         ticket: Ticket,
         notify_reviewer: Optional[bool] = False,
@@ -478,8 +462,8 @@ class TicketManager(TdxManager, TdxAppMixin, TdxCustomAttributeMixin):
     ) -> Ticket:
         """Creates a Ticket"""
         return self.dispatcher.send(
-            self._insert.method,
-            self._insert.url.format(
+            self._create.method,
+            self._create.url.format(
                 appId=self.app_id,
                 EnableNotifyReviewer=notify_reviewer,
                 NotifyRequestor=notify_requestor,
