@@ -30,10 +30,15 @@ from tdxapi.models.custom_attribute import CustomAttribute
 from tdxapi.models.custom_attribute_choice import CustomAttributeChoice
 from tdxapi.models.custom_attribute_list import CustomAttributeList
 from tdxapi.models.display_column import DisplayColumn
+from tdxapi.models.eligible_assignment import EligibleAssignment
 from tdxapi.models.feed_entry import FeedEntry
 from tdxapi.models.form import Form
 from tdxapi.models.functional_role import FunctionalRole
 from tdxapi.models.functional_role_search import FunctionalRoleSearch
+from tdxapi.models.group import Group
+from tdxapi.models.group_application import GroupApplication
+from tdxapi.models.group_member import GroupMember
+from tdxapi.models.impact import Impact
 from tdxapi.models.item_update import ItemUpdate
 from tdxapi.models.item_update_like import ItemUpdateLike
 from tdxapi.models.item_update_reply import ItemUpdateReply
@@ -41,6 +46,7 @@ from tdxapi.models.item_updates_page import ItemUpdatesPage
 from tdxapi.models.order_by_column import OrderByColumn
 from tdxapi.models.participant import Participant
 from tdxapi.models.permission import Permission
+from tdxapi.models.priority import Priority
 from tdxapi.models.product_model import ProductModel
 from tdxapi.models.product_model_search import ProductModelSearch
 from tdxapi.models.product_type import ProductType
@@ -53,7 +59,21 @@ from tdxapi.models.resource_pool import ResourcePool
 from tdxapi.models.resource_pool_search import ResourcePoolSearch
 from tdxapi.models.security_role import SecurityRole
 from tdxapi.models.security_role_search import SecurityRoleSearch
+from tdxapi.models.sla_assignment_options import SlaAssignmentOptions
+from tdxapi.models.sla_removal_options import SlaRemovalOptions
+from tdxapi.models.ticket import Ticket
+from tdxapi.models.ticket_feed_entry import TicketFeedEntry
 from tdxapi.models.ticket_listing import TicketListing
+from tdxapi.models.ticket_search import TicketSearch
+from tdxapi.models.ticket_source import TicketSource
+from tdxapi.models.ticket_status import TicketStatus
+from tdxapi.models.ticket_status_search import TicketStatusSearch
+from tdxapi.models.ticket_task import TicketTask
+from tdxapi.models.ticket_task_feed_entry import TicketTaskFeedEntry
+from tdxapi.models.ticket_type import TicketType
+from tdxapi.models.urgency import Urgency
+from tdxapi.models.user import User
+from tdxapi.models.user_application import UserApplication
 from tdxapi.models.vendor import Vendor
 from tdxapi.models.vendor_search import VendorSearch
 
