@@ -20,7 +20,7 @@ class AccountSearch(TdxModel):
     )
 
     #: The custom attributes to filter on.
-    custom_attributes = attr.ib(
+    attributes = attr.ib(
         default=attr.Factory(CustomAttributeList),
         converter=CustomAttributeList.from_data,
         metadata={"tdx_name": "CustomAttributes"},
