@@ -46,3 +46,6 @@ class Attachment(TdxModel):
 
     #: The uri to retrieve the attachment content.
     content_uri = attr.ib(default=None, metadata={"tdx_name": "ContentUri"})
+
+    #: The content of the attachment, or null if content is not being retrieved.
+    content = attr.ib(default=None, repr=False, eq=False)
