@@ -23,7 +23,7 @@ class ConfigurationItemSearch(TdxModel):
     )
 
     #: The custom attributes to filter on.
-    custom_attributes = attr.ib(
+    attributes = attr.ib(
         default=attr.Factory(CustomAttributeList),
         converter=CustomAttributeList.from_data,
         metadata={"tdx_name": "CustomAttributes"},
