@@ -29,7 +29,7 @@ class ContactInformation(TdxModel):
     state = attr.ib(default=None, metadata={"tdx_name": "State"})
 
     #: The postal code.
-    postal_code = attr.ib(default=None, metadata={"tdx_name": "PostalCode"})
+    zip = attr.ib(default=None, metadata={"tdx_name": "PostalCode"})
 
     #: The country.
     country = attr.ib(default=None, metadata={"tdx_name": "Country"})
