@@ -33,8 +33,10 @@ class ItemUpdateReply(TdxModel):
     #: The last name of the person making the reply.
     created_last_name = attr.ib(default=None, metadata={"tdx_name": "CreatedLastName"})
 
-    #: The path to the profile picture of the person making the reply.
-    created_pic_path = attr.ib(default=None, metadata={"tdx_name": "CreatedByPicPath"})
+    #: The profile image file name of the person making the reply.
+    created_profile_image_file_name = attr.ib(
+        default=None, metadata={"tdx_name": "CreatedByPicPath"}
+    )
 
     #: The date of the reply.
     created_date = attr.ib(
