@@ -23,7 +23,7 @@ class ReportSearch(TdxModel):
 
     #: The name of the system application to filter on. If specified, will only
     #: include reports belonging to this application.
-    app_name = attr.ib(default=None, metadata={"tdx_name": "ForApplicationName"})
+    app_class = attr.ib(default=None, metadata={"tdx_name": "ForApplicationName"})
 
     #: The id of the report source to filter on. If specified, will only include
     #: reports belonging to this report source.
