@@ -22,5 +22,7 @@ class ResourceItem(TdxModel):
     #: The reference id of the resource item.
     ref_id = attr.ib(default=None, metadata={"tdx_name": "RefValue"})
 
-    #: The path to the profile picture.
-    pic_path = attr.ib(default=None, metadata={"tdx_name": "ProfileImageFileName"})
+    #: The profile image file name of the resource.
+    profile_image_file_name = attr.ib(
+        default=None, metadata={"tdx_name": "ProfileImageFileName"}
+    )
